@@ -1,7 +1,10 @@
 """
-pycord.audio
-~~~~~~~~~~~~
+pycord.ext.audio
+~~~~~~~~~~~~~~~~
 Lavalink Module For Pycord
+
+:copyright: 2020 PythonistaGuild & 2021 Pycord
+:license: MIT see LICENSE for more info
 """
 
 from .client import Client
@@ -9,6 +12,7 @@ from .errors import *
 from .eqs import *
 from .events import *
 from .player import *
+from discord.ext.commands import *
 from .node import Node
 from .meta import audioMixin
 from .websocket import WebSocket
