@@ -1,7 +1,10 @@
 """
-pycord.dl
-~~~~~~~~~
+pycord.ext.dl
+~~~~~~~~~~~~~
 YouTube Video Downloader Specialized For Pycord
+
+:copyright: 2021 Pycord
+:license: MIT see LICENSE for more info
 """
 
 from __future__ import unicode_literals
